@@ -3,7 +3,7 @@ package WiringPi::API;
 use strict;
 use warnings;
 
-our $VERSION = '2.36.3';
+our $VERSION = '2.36.4';
 
 require XSLoader;
 XSLoader::load('WiringPi::API', $VERSION);
@@ -277,6 +277,7 @@ sub spi_data {
     if ($chan != 0 && $chan != 1){
         die "spi_data() channel param must be 0 or 1\n";
     }
+
     if (ref $data ne 'ARRAY'){
         die "spi_data() data param must be an array reference\n";
     }
@@ -287,7 +288,7 @@ sub spi_data {
     my $buf;
 
     for (@$data){
-        $buf += $_;
+        push @$buf, $_;
     }
 
     return spiDataRW($chan, $buf, $len);
@@ -398,7 +399,7 @@ These XS functions map directly to the wiringPi functions with their original
 names. 
 
 Note that C<setInterrupt> is a custom C wrapper for C<wiringPiISR()>, as is
-C<spiDataRW> for C<wiringPiSPIDataRW(). This is required in order to be able
+C<spiDataRW> for C<wiringPiSPIDataRW()>. This is required in order to be able
 to make them usable in Perl land.
 
     wiringPiSetup       wiringPiSetupSys    wiringPiSetupGpio
@@ -1109,7 +1110,8 @@ Maps to: C<int spiDataRW(int channel, AV* data, int len)>, which calls
 C<int wiringPiSPIDataRW(int channel, unsigned char* data, int len)>.
 
 Writes, and then reads a block of data over the SPI bus. The read following the
-write is read into the transmit buffer, so it'll be overwritten.
+write is read into the transmit buffer, so it'll be overwritten and sent back
+as a Perl array.
 
 Parameters:
 
@@ -1121,7 +1123,9 @@ C</dev/spidev0.0> and C<1> for channel C</dev/spidev0.1>.
     $data
 
 Mandatory: An array reference, with each element containing a single unsigned
-8-bit byte that you want to write to the device.
+8-bit byte that you want to write to the device. If you want to read-only, send
+in an aref with all the elements set to C<0>. These will be overwritten with
+the read data, and sent back as a Perl array.
 
     $len
 
@@ -1130,7 +1134,13 @@ array reference that will be sent to the device. I could just count the number
 of elements, but this keeps things consistent, and ensures the user is fully
 aware of the data they are sending on the bus.
 
-Returns the write buffer (C<$data>) after it's been written with the read data.
+Returns a Perl array containing the same number of elements you sent in. 
+
+    # read-only... three bytes
+
+    my $buf = [0x00, 0x00, 0x00];
+
+    my @ret = spiDataRW($chan, $buf, 3);
 
 =head1 BMP180 PRESSURE SENSOR FUNCTIONS
 
